@@ -180,12 +180,19 @@ impl<R: Read + Any + Send + Sync> WasiFile for ReadPipe<R> {
     async fn num_ready_bytes(&self) -> Result<u64, Error> {
         Ok(0)
     }
+    fn isatty(&self) -> bool {
+        false
+    }
     async fn readable(&self) -> Result<(), Error> {
         Err(Error::badf())
     }
     async fn writable(&self) -> Result<(), Error> {
         Err(Error::badf())
     }
+
+    async fn sock_accept(&mut self, fdflags: FdFlags) -> Result<Box<dyn WasiFile>, Error> {
+        Err(Error::badf())
+    }
 }
 
 /// A virtual pipe write end.
@@ -336,10 +343,17 @@ impl<W: Write + Any + Send + Sync> WasiFile for WritePipe<W> {
     async fn num_ready_bytes(&self) -> Result<u64, Error> {
         Ok(0)
     }
+    fn isatty(&self) -> bool {
+        false
+    }
     async fn readable(&self) -> Result<(), Error> {
         Err(Error::badf())
     }
     async fn writable(&self) -> Result<(), Error> {
         Err(Error::badf())
     }
+
+    async fn sock_accept(&mut self, fdflags: FdFlags) -> Result<Box<dyn WasiFile>, Error> {
+        Err(Error::badf())
+    }
 }
